# easytext
让自然语言模型训练更容易

## 安装

`pip install easytext-nlp`

注意: pip repository 中存在一个 easytext，不是本项目，不要安装错了。
也就是 `pip install easytext` 并非安装的是本项目。

# event

事件识别以及事件要素识别模型。

## event_detection_without_tirgger

ACL 2019 论文，忽略触发词的事件类型检测。[相关论文](https://www.aclweb.org/anthology/N19-1080/)
和 [我的简书](https://www.jianshu.com/p/01deb5b22240)

更加详细说明，请参考: `docs:event:event_detection_without_trigger`

训练命令: `python -m event.event_detection_without_tirgger.train`


# ner

命名实体识别相关模型


# acsa

属性级情感分析

